diff --git a/ChangeLog b/ChangeLog
index 310763b7..a48197a1 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,8 @@
+2011-11-11  Nicolas François  <nicolas.francois@centraliens.net>
+
+	* libmisc/copydir.c: Avoid conflict with glibc. Rename error to
+	error_acl.
+
 2011-11-11  Nicolas François  <nicolas.francois@centraliens.net>
 
 	* man/newusers.8.xml: Document the optional file argument.
diff --git a/libmisc/copydir.c b/libmisc/copydir.c
index 5c6c0594..1774aeff 100644
--- a/libmisc/copydir.c
+++ b/libmisc/copydir.c
@@ -174,9 +174,9 @@ int reset_selinux_file_context (void)
 
 #if defined(WITH_ACL) || defined(WITH_ATTR)
 /*
  * error - format the error messages for the ACL and EQ libraries.
  */
-static void error (struct error_context *ctx, const char *fmt, ...)
+static void error_acl (struct error_context *ctx, const char *fmt, ...)
 {
 	va_list ap;
 
@@ -190,7 +190,7 @@ static void error (struct error_context *ctx, const char *fmt, ...)
 }
 
 static struct error_context ctx = {
-	error
+	error_acl
 };
 #endif				/* WITH_ACL || WITH_ATTR */
@@ -174,9 +174,9 @@ int reset_selinux_file_context (void)
 #if defined(WITH_ACL) || defined(WITH_ATTR)
 /*
- * error - format the error messages for the ACL and EQ libraries.
+ * error_acl - format the error messages for the ACL and EQ libraries.
  */